Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4841)

Unified Diff: chrome/browser/ui/tabs/tab_strip_model_observer.h

Issue 11359201: Remove TabContents from TabStripModelObserver::TabReplacedAt. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/tabs/tab_strip_model.cc ('k') | chrome/browser/ui/tabs/tab_strip_model_observer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/tabs/tab_strip_model_observer.h
diff --git a/chrome/browser/ui/tabs/tab_strip_model_observer.h b/chrome/browser/ui/tabs/tab_strip_model_observer.h
index d1d655488634e08f5a4aebbd689119e24130c1d0..5924a95bbe22b9ed79ae533c9303254d6824a101 100644
--- a/chrome/browser/ui/tabs/tab_strip_model_observer.h
+++ b/chrome/browser/ui/tabs/tab_strip_model_observer.h
@@ -5,7 +5,6 @@
#ifndef CHROME_BROWSER_UI_TABS_TAB_STRIP_MODEL_OBSERVER_H_
#define CHROME_BROWSER_UI_TABS_TAB_STRIP_MODEL_OBSERVER_H_
-class TabContents;
class TabStripModel;
class TabStripSelectionModel;
@@ -22,7 +21,7 @@ class WebContents;
//
// Two major implementers are the TabStrip, which uses notifications sent
// via this interface to update the presentation of the strip, and the Browser
// object, which updates bookkeeping and shows/hides individual TabContentses.
//
// Register your TabStripModelObserver with the TabStripModel using its
// Add/RemoveObserver methods.
@@ -104,12 +103,12 @@ class TabStripModelObserver {
int index,
TabChangeType change_type);
// The tab contents was replaced at the specified index. This is invoked
// when instant is enabled and the user navigates by way of instant or when
// prerendering swaps in a prerendered TabContents.
virtual void TabReplacedAt(TabStripModel* tab_strip_model,
- TabContents* old_contents,
- TabContents* new_contents,
+ content::WebContents* old_contents,
+ content::WebContents* new_contents,
int index);
// Invoked when the pinned state of a tab changes. See note in
« no previous file with comments | « chrome/browser/ui/tabs/tab_strip_model.cc ('k') | chrome/browser/ui/tabs/tab_strip_model_observer.cc » ('j') | no next file with comments »
@@ -22,7 +21,7 @@ class WebContents;
// Two major implementers are the TabStrip, which uses notifications sent
// via this interface to update the presentation of the strip, and the Browser
-// object, which updates bookkeeping and shows/hides individual TabContentses.
+// object, which updates bookkeeping and shows/hides individual WebContentses.
//
// Register your TabStripModelObserver with the TabStripModel using its
@@ -104,12 +103,12 @@ class TabStripModelObserver {
int index,
TabChangeType change_type);
- // The tab contents was replaced at the specified index. This is invoked
+ // The WebContents was replaced at the specified index. This is invoked
// when instant is enabled and the user navigates by way of instant or when
@@ -104,12 +103,12 @@ class TabStripModelObserver {
// when instant is enabled and the user navigates by way of instant or when
- // prerendering swaps in a prerendered TabContents.
+ // prerendering swaps in a prerendered WebContents.
virtual void TabReplacedAt(TabStripModel* tab_strip_model,

Powered by Google App Engine
This is Rietveld 408576698